@@ -3,6 +3,9 @@ from .drop_oldest_duplicate_transformer import (  # noqa: F401
 )
 from .dropColumnsTransformer_nc import DropColumnsTransformerNC  # noqa: F401
 from .join_dataframes_transformer import JoinDataframesTransformerNC  # noqa: F401
+from .select_and_cast_columns_transformer_nc import (  # noqa: F401
+    SelectAndCastColumnsTransformerNC,
+)
 from .selectColumnsTransformer_nc import SelectColumnsTransformerNC  # noqa: F401
 from .simple_sql_transformer import SimpleSqlServerTransformer  # noqa: F401
 from .timezone_transformer_nc import TimeZoneTransformerNC  # noqa: F401
